Django-Access
=============

The application introducing dynamic evaluation-based instance-level (row-level) access rights control for Django.

See details at the home page: https://github.com/nnseva/django-access
